package com.lantone.qc.kernel.catalogue.beilun.majorInspection;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.PacsDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : MEDI03112
 * @Description :  医嘱存在MR,报告单未记录
 * @Author : zh
 * @Date: 2021-04-06 17:06
 */
public class MEDI03112 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        int ctNum = 0;
        int bcNum = 0;
        List<DoctorAdviceDoc> doctorAdviceDocsList = inputInfo.getDoctorAdviceDocs();
        if (ListUtil.isNotEmpty(doctorAdviceDocsList)) {
            for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocsList) {
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String state = doctorAdviceDocStructureMap.get("医嘱状态判别");
                if(StringUtil.isEmpty(state)){
                    continue;
                }
                if(state.equals("在用")) {
                    //ct取临时医嘱
                    String doctorAsks = doctorAdviceDocStructureMap.get("医嘱类型判别");
                    if (StringUtil.isNotEmpty(doctorAsks)) {
                        if ("临时医嘱".equals(doctorAsks)) {
                            //取医嘱项目名称
                            String daItemName = doctorAdviceDocStructureMap.get("医嘱项目名称");
                            if (daItemName.contains("磁共振") || daItemName.contains("MR")) {
                                if (!daItemName.contains("IMRT") && !daItemName.contains("mrs评分")) {
                                    ctNum++;

                                    continue;
                                }
                            }
                        }
                    }
                }
            }
            List<PacsDoc> pacsDocs = inputInfo.getPacsDocs();
            if(ListUtil.isNotEmpty(pacsDocs)){
                if(pacsDocs.size()>0) {
                    for (PacsDoc pacsDoc : pacsDocs) {
                        String pacsDocStr = pacsDoc.getStructureMap().get("报告名称");
                        if (StringUtil.isNotEmpty(pacsDocStr) && pacsDocStr.contains("MR")) {
                            bcNum++;
                        }
                    }
                }
            }
            if (ctNum != bcNum) {
                status.set("-1");
            }

        }
    }
}
